@@ -34,11 +34,13 @@ for url in open('pyano.conf'):
     conn.request("HEAD", path, '', {'User-Agent':  useragent})
     r = conn.getresponse()
     lm = r.getheader('Last-Modified')
-    table.append((url,rfc822.mktime_tz(rfc822.parsedate_tz(lm))))
+    site = SiteInfo()
+    site.url = url
+    site.last_modified = rfc822.mktime_tz(rfc822.parsedate_tz(lm))
+    table.append(site)
 
-
-table.sort(lambda x,y : -cmp(x[1], y[1]))
+table.sort(lambda x,y : -cmp(x.last_modified, y.last_modified))
 for i in  table:
     # print time.localtime(i[1])
-    print i[0], time.strftime("%Y-%m-%d %H:%M:%S %Z",time.localtime(i[1]))
+    print i.url, time.strftime("%Y-%m-%d %H:%M:%S %Z",time.localtime(i.last_modified))
 
